@@ -6,22 +6,19 @@ Gestion des erreurs de l'API
 """
 
 from blueflask.lib.errors import HTTPError
-from .. import SERVICE_CODE
+from ..consts import SERVICE_CODE
 
 
 ERRORS = {
     5000: (500, "serveur RabbitMQ de l'application injoignable"),
     5003: (503, "erreur de connexion à l'ocs"),
-    5004: (504, "ocs trop lent à répondre")
-    }
+    5004: (504, "ocs trop lent à répondre"),
+}
 
 
 def error(code, message=None):
     return HTTPError(ERRORS[code][0]).response(
         message=message or ERRORS[code][1],
-        code='{service_code}-{code}'.format(
-            service_code=SERVICE_CODE,
-            code=code
-            ),
+        code="{service_code}-{code}".format(service_code=SERVICE_CODE, code=code),
         service_code=SERVICE_CODE,
-        )
+    )
